@@ -21,9 +21,9 @@ def main(args):
         exec_command([domain_data['editor'], domain_data['solutions']])
         return
 
-    setattr(args, 'mission', [args.mission])
+    setattr(args, 'mission', [args.mission.replace('_', '-')])
     filename = get_filename_init(args)
-    open_editor([domain_data['editor'], filename])
+    exec_command([domain_data['editor'], filename])
 
 def main_upgrade(args):
     exec_command([sys.executable, '-mpip', 'install', '--upgrade', 'checkio-client'])
\ No newline at end of file
