@@ -7,6 +7,10 @@ import shlex
 from checkio_client.eoc_runner import init_subparsers as eoc_init_subparsers,\
     add_check_paramas
 import logging
+import platform
+
+#import pdb; pdb.set_trace();
+
 LEVELS = [logging.CRITICAL, logging.ERROR, logging.WARNING, logging.INFO, logging.DEBUG]
 
 parser = argparse.ArgumentParser(prog='checkio')
@@ -82,6 +86,7 @@ p_repo_check = subparsers.add_parser('checkrepo', help='you can test your missio
 p_repo_check.add_argument('folder', type=str, default='.', nargs=1,
     metavar='folder',
     help='path to the repository folder')
+p_repo_check.add_argument('--translation', type=str)
 p_repo_check.set_defaults(module='repo_check')
 
 p_check_after = subparsers.add_parser('check', help='test your solution')
@@ -188,7 +193,10 @@ def apply_main_args(args=None):
 
 def main():
     # because of calling inside of #!/usr/bin/
-    call_args = sum(map(lambda a: shlex.split(a), sys.argv[1:]), [])
+    if platform.system() == 'Windows':
+        call_args = sys.argv[1:]
+    else:
+        call_args = sum(map(lambda a: shlex.split(a), sys.argv[1:]), [])
     args = parser.parse_args(call_args)
 
     logging.basicConfig(level=LEVELS[args.verbose])
