@@ -8,7 +8,7 @@ import socket
 __all__ = ['conf']
 CUR_DIR = os.path.dirname(__file__)
 
-VERSION = (0, 2, 9)
+VERSION = (0, 2, 15)
 
 TRANSFER_PARAMETERS = ('executable', 'editor', 'solutions');
 
@@ -19,7 +19,11 @@ def get_fodler(folder):
     return os.path.expanduser(os.path.join('~', folder))
 
 class Config(configparser.ConfigParser):
-    foldername = os.path.join(os.path.expanduser("~"), '.checkio')
+    xdg = os.getenv('XDG_CONFIG_HOME')
+    if xdg:
+        foldername = os.path.join(xdg, 'checkio')
+    else:
+        foldername = os.path.join(os.path.expanduser("~"), '.checkio')
     filename = os.path.join(foldername, 'config.ini')
     editor = 'open'
     docker_ip = '172.17.0.1'
@@ -47,7 +51,7 @@ class Config(configparser.ConfigParser):
         'js': {
             'url_main': 'https://js.checkio.org',
             'server_port': 2345,
-            'server_host': 'py-tester.checkio.org',
+            'server_host': 'js-tester.checkio.org',
             'center_slug': 'js-node',
             #'executable': 'node',
             'extension': 'js',
